#include "Arduino.h"
#include <LiquidCrystal.h>
#include <BasicStepperDriver.h>

#include "Scenerunner.h"

Scenerunner::Scenerunner(LiquidCrystal *lcd, BasicStepperDriver *stepper, int pin_focus, int pin_shutter) {
  _lcd = lcd;
  _stepper = stepper;
  _pin_focus = pin_focus;
  _pin_shutter = pin_shutter;
}

void Scenerunner::start() {
  _lcd->clear();
  _lcd->print("Running...");
  steps_left = nSteps;
  runStep = RUN_SETTLE;
  runStepStart = millis();
}

void Scenerunner::nextAction() {
  _lcd->setCursor(0, 1);
  switch (runStep) {
    case RUN_OFF:
      _lcd->print("rS: OFF ");
      break;
    case RUN_SETTLE:
      _lcd->print("rS: SETTLE ");
      if (millis() >= runStepStart + tSettle) {
        runStep = RUN_FOCUS;
	runStepStart = millis();
      }
      break;
    case RUN_FOCUS:
      _lcd->print("rS: FOCUS ");
      if (millis() >= runStepStart + tFocus) {
        runStep = RUN_SHUTTER;
	runStepStart = millis();
      }
      break;
    case RUN_SHUTTER:
      _lcd->print("rS: SHUTTER ");
      if (millis() >= runStepStart + tShutter) {
        runStep = RUN_MOVE;
	runStepStart = millis();
      }
      break;
    case RUN_MOVE:
      _lcd->print("rS: MOVE ");
      if (millis() >= runStepStart + 1234) {
	// dummy wait time
        runStep = RUN_SETTLE;
	runStepStart = millis();
      }
      break;
    case RUN_RETURN:
      _lcd->print("rS: RETURN ");
      break;
  }
}
